"""Bigbench group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval."

BIGBENCH_TASKS = {
    # Tag-based groups
    "bigbench_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_multiple_choice_a": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_multiple_choice_b": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    # Individual tasks
    "bigbench_abstract_narrative_understanding_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_abstract_narrative_understanding_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_anachronisms_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_anachronisms_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_analogical_similarity_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_analogical_similarity_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_analytic_entailment_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_analytic_entailment_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_arithmetic_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_arithmetic_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_ascii_word_recognition_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_authorship_verification_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_authorship_verification_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_auto_categorization_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_auto_debugging_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_bbq_lite_json_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_bbq_lite_json_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_bridging_anaphora_resolution_barqa_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_causal_judgment_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_causal_judgment_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_cause_and_effect_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_cause_and_effect_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_checkmate_in_one_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_checkmate_in_one_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_chess_state_tracking_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_chinese_remainder_theorem_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_cifar10_classification_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_cifar10_classification_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_code_line_description_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_code_line_description_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_codenames_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_color_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_color_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_common_morpheme_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_common_morpheme_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_conceptual_combinations_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_conceptual_combinations_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_conlang_translation_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_contextual_parametric_knowledge_conflicts_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_contextual_parametric_knowledge_conflicts_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_crash_blossom_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_crash_blossom_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_crass_ai_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_crass_ai_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_cryobiology_spanish_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_cryobiology_spanish_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_cryptonite_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_cs_algorithms_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_cs_algorithms_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_dark_humor_detection_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_dark_humor_detection_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_date_understanding_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_date_understanding_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_disambiguation_qa_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_disambiguation_qa_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_discourse_marker_prediction_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_discourse_marker_prediction_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_disfl_qa_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_dyck_languages_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_dyck_languages_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_elementary_math_qa_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_elementary_math_qa_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_emoji_movie_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_emoji_movie_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_emojis_emotion_prediction_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_emojis_emotion_prediction_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_empirical_judgments_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_empirical_judgments_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_english_proverbs_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_english_proverbs_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_english_russian_proverbs_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_english_russian_proverbs_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_entailed_polarity_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_entailed_polarity_hindi_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_entailed_polarity_hindi_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_entailed_polarity_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_epistemic_reasoning_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_epistemic_reasoning_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_evaluating_information_essentiality_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_evaluating_information_essentiality_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_fact_checker_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_fact_checker_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_fantasy_reasoning_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_fantasy_reasoning_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_few_shot_nlg_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_figure_of_speech_detection_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_figure_of_speech_detection_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_formal_fallacies_syllogisms_negation_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_formal_fallacies_syllogisms_negation_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_gem_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_gender_inclusive_sentences_german_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_general_knowledge_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_general_knowledge_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_geometric_shapes_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_geometric_shapes_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_goal_step_wikihow_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_goal_step_wikihow_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_gre_reading_comprehension_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_gre_reading_comprehension_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_hhh_alignment_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_hhh_alignment_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_hindi_question_answering_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_hindu_knowledge_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_hindu_knowledge_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_hinglish_toxicity_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_hinglish_toxicity_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_human_organs_senses_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_human_organs_senses_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_hyperbaton_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_hyperbaton_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_identify_math_theorems_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_identify_math_theorems_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_identify_odd_metaphor_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_identify_odd_metaphor_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_implicatures_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_implicatures_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_implicit_relations_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_implicit_relations_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_intent_recognition_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_intent_recognition_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_international_phonetic_alphabet_nli_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_international_phonetic_alphabet_nli_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_international_phonetic_alphabet_transliterate_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_intersect_geometry_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_intersect_geometry_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_irony_identification_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_irony_identification_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_kanji_ascii_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_kanji_ascii_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_kannada_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_kannada_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_key_value_maps_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_key_value_maps_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_known_unknowns_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_known_unknowns_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_language_games_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_language_identification_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_language_identification_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_linguistic_mappings_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_linguistics_puzzles_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_list_functions_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_logic_grid_puzzle_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_logic_grid_puzzle_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_logical_args_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_logical_args_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_logical_deduction_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_logical_deduction_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_logical_fallacy_detection_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_logical_fallacy_detection_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_logical_sequence_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_logical_sequence_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_mathematical_induction_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_mathematical_induction_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_matrixshapes_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_metaphor_boolean_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_metaphor_boolean_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_metaphor_understanding_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_metaphor_understanding_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_minute_mysteries_qa_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_misconceptions_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_misconceptions_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_misconceptions_russian_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_misconceptions_russian_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_mnist_ascii_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_mnist_ascii_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_modified_arithmetic_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_moral_permissibility_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_moral_permissibility_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_movie_dialog_same_or_different_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_movie_dialog_same_or_different_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_movie_recommendation_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_movie_recommendation_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_mult_data_wrangling_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_multiemo_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_multiemo_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_multiple_choice_a": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_multiple_choice_b": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_natural_instructions_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_navigate_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_navigate_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_nonsense_words_grammar_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_nonsense_words_grammar_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_novel_concepts_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_novel_concepts_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_object_counting_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_odd_one_out_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_odd_one_out_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_operators_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_paragraph_segmentation_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_parsinlu_qa_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_parsinlu_qa_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_parsinlu_reading_comprehension_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_penguins_in_a_table_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_penguins_in_a_table_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_periodic_elements_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_periodic_elements_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_persian_idioms_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_persian_idioms_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_phrase_relatedness_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_phrase_relatedness_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_physical_intuition_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_physical_intuition_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_physics_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_physics_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_physics_questions_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_play_dialog_same_or_different_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_play_dialog_same_or_different_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_polish_sequence_labeling_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_presuppositions_as_nli_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_presuppositions_as_nli_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_qa_wikidata_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_question_selection_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_question_selection_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_real_or_fake_text_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_real_or_fake_text_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_reasoning_about_colored_objects_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_reasoning_about_colored_objects_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_repeat_copy_logic_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_rephrase_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_riddle_sense_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_riddle_sense_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_ruin_names_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_ruin_names_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_salient_translation_error_detection_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_salient_translation_error_detection_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_scientific_press_release_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_semantic_parsing_in_context_sparc_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_semantic_parsing_spider_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_sentence_ambiguity_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_sentence_ambiguity_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_similarities_abstraction_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_similarities_abstraction_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_simp_turing_concept_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_simple_arithmetic_json_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_simple_arithmetic_json_subtasks_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_simple_ethical_questions_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_simple_ethical_questions_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_simple_text_editing_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_snarks_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_snarks_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_social_iqa_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_social_iqa_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_social_support_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_social_support_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_sports_understanding_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_sports_understanding_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_strange_stories_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_strange_stories_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_strategyqa_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_strategyqa_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_sufficient_information_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_suicide_risk_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_suicide_risk_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_swahili_english_proverbs_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_swahili_english_proverbs_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_swedish_to_german_proverbs_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_swedish_to_german_proverbs_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_symbol_interpretation_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_symbol_interpretation_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_temporal_sequences_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_temporal_sequences_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_tense_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_timedial_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_timedial_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_topical_chat_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_tracking_shuffled_objects_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_tracking_shuffled_objects_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_understanding_fables_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_understanding_fables_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_undo_permutation_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_undo_permutation_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_unit_conversion_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_unit_conversion_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_unit_interpretation_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_unit_interpretation_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_unnatural_in_context_learning_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_vitaminc_fact_verification_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_vitaminc_fact_verification_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_what_is_the_tao_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_what_is_the_tao_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_which_wiki_edit_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_which_wiki_edit_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_winowhy_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_winowhy_multiple_choice": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_word_sorting_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
    "bigbench_word_unscrambling_generate_until": f"{BASE_IMPORT}bigbench:BigBenchExtractor",
}
