"""Flores group task manifest - Part 1 (A-E language pairs)."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval."

FLORES_TASKS_PART1 = {
    "african_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "african_flores_tasks": f"{BASE_IMPORT}flores:FloresExtractor",
    "darija_translation_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "darija_translation_tasks_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ace_Arab-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ace_Arab-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ace_Arab-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ace_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ace_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ace_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_acq_Arab-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_acq_Arab-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_acq_Arab-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_aeb_Arab-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_aeb_Arab-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_aeb_Arab-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_afr-eng": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_afr-eng_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_afr-eng_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_afr-eng_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_afr_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_afr_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_afr_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_aka_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_aka_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_aka_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_amh_Ethi-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_amh_Ethi-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_amh_Ethi-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ary_Arab-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ary_Arab-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ary_Arab-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_arz_Arab-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_arz_Arab-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_arz_Arab-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_bam_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_bam_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_bam_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ban_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ban_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ban_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_bem_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_bem_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_bem_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca-de": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca-en": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca-es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca-eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca-fr": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca-gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca-it": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ca-pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_cjk_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_cjk_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_cjk_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_de-ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_de-es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_de-eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_de-gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_de-pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_dik_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_dik_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_dik_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_dyu_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_dyu_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_dyu_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_en-ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_en-es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_en-eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_en-gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_en-pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng-afr": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng-afr_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng-afr_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng-afr_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ace_Arab_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ace_Arab_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ace_Arab_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ace_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ace_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ace_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-acq_Arab_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-acq_Arab_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-acq_Arab_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-aeb_Arab_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-aeb_Arab_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-aeb_Arab_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-afr_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-afr_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-afr_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-aka_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-aka_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-aka_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-amh_Ethi_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-amh_Ethi_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-amh_Ethi_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ary_Arab_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ary_Arab_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ary_Arab_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-arz_Arab_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-arz_Arab_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-arz_Arab_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-bam_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-bam_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-bam_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ban_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ban_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ban_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-bem_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-bem_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-bem_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-cjk_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-cjk_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-cjk_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-dik_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-dik_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-dik_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-dyu_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-dyu_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-dyu_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ewe_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ewe_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ewe_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fon_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fon_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fon_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fra_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fra_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fra_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fuv_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fuv_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-fuv_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-gaz_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-gaz_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-gaz_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-hau_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-hau_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-hau_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ibo_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ibo_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ibo_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kab_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kab_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kab_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kam_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kam_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kam_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kbp_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kbp_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kbp_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kea_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kea_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kea_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kik_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kik_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kik_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kin_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kin_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kin_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kmb_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kmb_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kmb_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-knc_Arab_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-knc_Arab_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-knc_Arab_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-knc_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-knc_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-knc_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kon_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kon_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-kon_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lin_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lin_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lin_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lua_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lua_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lua_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lug_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lug_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-lug_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-luo_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-luo_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-luo_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-mos_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-mos_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-mos_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nso_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nso_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nso_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nus_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nus_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nus_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nya_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nya_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-nya_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-plt_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-plt_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-plt_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-run_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-run_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-run_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sag_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sag_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sag_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sna_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sna_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sna_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-som_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-som_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-som_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sot_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sot_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sot_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ssw_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ssw_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-ssw_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sun_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sun_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-sun_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-swh_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-swh_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-swh_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-taq_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-taq_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-taq_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
}
