"""Kobest group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval."

KOBEST_TASKS = {
    "kobest": f"{BASE_IMPORT}kobest:KobestExtractor",
    "kobest_boolq": f"{BASE_IMPORT}kobest:KobestExtractor",
    "kobest_copa": f"{BASE_IMPORT}kobest:KobestExtractor",
    "kobest_hellaswag": f"{BASE_IMPORT}kobest:KobestExtractor",
    "kobest_sentineg": f"{BASE_IMPORT}kobest:KobestExtractor",
    "kobest_wic": f"{BASE_IMPORT}kobest:KobestExtractor",
}
