"""Blimp group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval."

BLIMP_TASKS = {
    "blimp": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_adjunct_island": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_anaphor_gender_agreement": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_anaphor_number_agreement": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_animate_subject_passive": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_animate_subject_trans": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_causative": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_complex_NP_island": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_coordinate_structure_constraint_complex_left_branch": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_coordinate_structure_constraint_object_extraction": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_determiner_noun_agreement_1": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_determiner_noun_agreement_2": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_determiner_noun_agreement_irregular_1": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_determiner_noun_agreement_irregular_2": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_determiner_noun_agreement_with_adj_2": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_determiner_noun_agreement_with_adj_irregular_1": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_determiner_noun_agreement_with_adj_irregular_2": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_determiner_noun_agreement_with_adjective_1": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_distractor_agreement_relational_noun": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_distractor_agreement_relative_clause": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_drop_argument": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_ellipsis_n_bar_1": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_ellipsis_n_bar_2": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_existential_there_object_raising": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_existential_there_quantifiers_1": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_existential_there_quantifiers_2": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_existential_there_subject_raising": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_expletive_it_object_raising": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_inchoative": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_intransitive": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_irregular_past_participle_adjectives": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_irregular_past_participle_verbs": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_irregular_plural_subject_verb_agreement_1": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_irregular_plural_subject_verb_agreement_2": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_left_branch_island_echo_question": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_left_branch_island_simple_question": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_matrix_question_npi_licensor_present": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_npi_present_1": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_npi_present_2": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_only_npi_licensor_present": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_only_npi_scope": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_passive_1": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_passive_2": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_principle_A_c_command": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_principle_A_case_1": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_principle_A_case_2": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_principle_A_domain_1": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_principle_A_domain_2": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_principle_A_domain_3": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_principle_A_reconstruction": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_regular_plural_subject_verb_agreement_1": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_regular_plural_subject_verb_agreement_2": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_sentential_negation_npi_licensor_present": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_sentential_negation_npi_scope": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_sentential_subject_island": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_superlative_quantifiers_1": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_superlative_quantifiers_2": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_tough_vs_raising_1": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_tough_vs_raising_2": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_transitive": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_wh_island": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_wh_questions_object_gap": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_wh_questions_subject_gap": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_wh_questions_subject_gap_long_distance": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_wh_vs_that_no_gap": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_wh_vs_that_no_gap_long_distance": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_wh_vs_that_with_gap": f"{BASE_IMPORT}blimp:BlimpExtractor",
    "blimp_wh_vs_that_with_gap_long_distance": f"{BASE_IMPORT}blimp:BlimpExtractor",
}
