"""CMMLU group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval."

# All CMMLU task names
CMMLU_TASKS = {
    "cmmlu_agronomy": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_anatomy": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_ancient_chinese": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_arts": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_astronomy": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_business_ethics": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_chinese_civil_service_exam": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_chinese_driving_rule": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_chinese_food_culture": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_chinese_foreign_policy": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_chinese_history": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_chinese_literature": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_chinese_teacher_qualification": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_clinical_knowledge": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_college_actuarial_science": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_college_education": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_college_engineering_hydrology": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_college_law": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_college_mathematics": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_college_medical_statistics": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_college_medicine": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_computer_science": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_computer_security": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_conceptual_physics": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_construction_project_management": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_economics": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_education": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_electrical_engineering": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_elementary_chinese": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_elementary_commonsense": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_elementary_information_and_technology": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_elementary_mathematics": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_ethnology": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_food_science": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_genetics": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_global_facts": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_high_school_biology": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_high_school_chemistry": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_high_school_geography": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_high_school_mathematics": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_high_school_physics": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_high_school_politics": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_human_sexuality": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_international_law": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_journalism": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_jurisprudence": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_legal_and_moral_basis": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_logical": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_machine_learning": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_management": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_marketing": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_marxist_theory": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_modern_chinese": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_nutrition": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_philosophy": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_professional_accounting": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_professional_law": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_professional_medicine": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_professional_psychology": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_public_relations": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_security_study": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_sociology": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_sports_science": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_traditional_chinese_medicine": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_virology": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_world_history": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
    "cmmlu_world_religions": f"{BASE_IMPORT}cmmlu:CmmluExtractor",
}
