import os as _os
_base = _os.path.dirname(__file__)
for _root, _dirs, _files in _os.walk(_base):
    _dirs[:] = sorted(d for d in _dirs if not d.startswith((".", "_")))
    if _root != _base:
        __path__.append(_root)

# Include geometry namespace for cross-tree relative imports
_geo = _os.path.dirname(_base)
for _root, _dirs, _files in _os.walk(_geo):
    _dirs[:] = sorted(d for d in _dirs if not d.startswith((".", "_")))
    if _root != _geo and _root != _base:
        __path__.append(_root)

"""Auto-grouped modules."""
from .runner import (
    run_full_zwiad,
    run_full_zwiad_with_layer_search,
    run_full_zwiad_with_steering_eval,
    evaluate_steering_effectiveness,
    evaluate_activation_regions,
    compute_geometry_metrics,
)
