"""Belebele group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval."

BELEBELE_TASKS = {
    "belebele": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_acm_Arab": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_afr_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_afr_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_afr_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_afr_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_afr_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_afr_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_als_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_amh_Ethi": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_amh_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_amh_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_amh_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_amh_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_amh_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_apc_Arab": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_arb_Arab": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_arb_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ars_Arab": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ary_Arab": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ary_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ary_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ary_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ary_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ary_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_arz_Arab": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_arz_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_arz_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_arz_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_arz_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_arz_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_asm_Beng": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_azj_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_bam_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_bam_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_bam_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_bam_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_bam_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_bam_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ben_Beng": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ben_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_bod_Tibt": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_bul_Cyrl": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_cat_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ceb_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ces_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ckb_Arab": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_dan_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_deu_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ell_Grek": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_eng_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_eng_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_eng_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_eng_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_eng_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_eng_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_est_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_eus_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_fin_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_fra_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_fra_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_fra_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_fra_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_fra_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_fra_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_fuv_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_fuv_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_fuv_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_fuv_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_fuv_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_fuv_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_gaz_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_gaz_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_gaz_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_gaz_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_gaz_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_gaz_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_glg_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_grn_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_guj_Gujr": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_hat_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_hau_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_hau_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_hau_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_hau_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_hau_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_hau_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_heb_Hebr": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_hin_Deva": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_hin_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_hrv_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_hun_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_hye_Armn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ibo_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ibo_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ibo_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ibo_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ibo_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ibo_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ilo_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ind_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_isl_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ita_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_jav_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_jpn_Jpan": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kac_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kan_Knda": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kat_Geor": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kaz_Cyrl": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kea_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kea_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kea_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kea_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kea_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kea_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_khk_Cyrl": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_khm_Khmr": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kin_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kin_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kin_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kin_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kin_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kin_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kir_Cyrl": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_kor_Hang": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_lao_Laoo": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_lin_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_lin_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_lin_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_lin_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_lin_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_lin_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_lit_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_lug_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_lug_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_lug_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_lug_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_lug_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_lug_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_luo_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_luo_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_luo_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_luo_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_luo_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_luo_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_lvs_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_mal_Mlym": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_mar_Deva": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_mkd_Cyrl": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_mlt_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_mri_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_mya_Mymr": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_nld_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_nob_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_npi_Deva": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_npi_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_nso_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_nya_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_nya_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_nya_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_nya_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_nya_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_nya_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ory_Orya": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_pan_Guru": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_pbt_Arab": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_pes_Arab": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_plt_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_plt_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_plt_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_plt_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_plt_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_plt_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_pol_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_por_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_por_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_por_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_por_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_por_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_por_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ron_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_rus_Cyrl": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_shn_Mymr": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_sin_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_sin_Sinh": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_slk_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_slv_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_sna_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_sna_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_sna_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_sna_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_sna_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_sna_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_snd_Arab": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_som_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_som_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_som_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_som_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_som_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_som_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_sot_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_sot_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_sot_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_sot_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_sot_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_sot_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_spa_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_srp_Cyrl": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ssw_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ssw_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ssw_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ssw_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ssw_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ssw_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_sun_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_swa_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_swa_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_swa_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_swa_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_swa_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_swe_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_swh_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tam_Taml": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tasks": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tel_Telu": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tgk_Cyrl": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tgl_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tha_Thai": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tir_Ethi": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tir_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tir_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tir_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tir_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tir_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tsn_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tsn_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tsn_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tsn_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tsn_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tsn_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tso_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tso_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tso_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tso_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tso_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tso_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_tur_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_ukr_Cyrl": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_urd_Arab": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_urd_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_uzn_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_vie_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_war_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_wol_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_wol_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_wol_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_wol_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_wol_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_wol_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_xho_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_xho_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_xho_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_xho_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_xho_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_xho_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_yor_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_yor_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_yor_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_yor_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_yor_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_yor_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_zho_Hans": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_zho_Hant": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_zsm_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_zul_Latn": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_zul_prompt_1": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_zul_prompt_2": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_zul_prompt_3": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_zul_prompt_4": f"{BASE_IMPORT}belebele:BelebeleExtractor",
    "belebele_zul_prompt_5": f"{BASE_IMPORT}belebele:BelebeleExtractor",
}
